<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="et">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.systemmonitor.systemserver.set!message" line="0"/>
			<source>Authentication is required to set service startup type</source>
			<translation>Süsteemi käivitusrakenduse määramiseks on vajalik autentimine</translation>
		</message>
		<message>
			<location filename="org.deepin.systemmonitor.systemserver.set!description" line="0"/>
			<source>Set service startup type</source>
			<translation>Määrake süsteemi käivitusrakendus</translation>
		</message>
	</context>
</TS>